@@ -28,7 +28,7 @@ double information(double numberindividuals,double sigma)
 
 void converthtophi(vector<vector<double> >& h,vector<vector<double> >& z,vector<double>& phi,vector<double>& parameters,double delta0,double newdelta,double sigma)
 {//converthtophi calculates probability of stopping for efficacy at each stage
-  int i,j;
+  size_t i,j;
 
  phi.clear();
  
@@ -55,7 +55,7 @@ void converthtophi(vector<vector<double> >& h,vector<vector<double> >& z,vector<
 double expectedsamplesize(vector<double> phi,vector<double> psi,vector<double> parameters)
 {
 
-  int i;
+  size_t i;
   double expectedsamplesize=0;
 
   for(i=0;i<phi.size();i++)
@@ -68,7 +68,7 @@ double expectedsamplesize(vector<double> phi,vector<double> psi,vector<double> p
 
 void converthtopsi(vector<vector<double> >& h,vector<vector<double> >& z,vector<double>& psi,vector<double>& parameters,double delta0,double newdelta,double sigma)
 {
-  int i,j;
+  size_t i,j;
 
  psi.clear();
  
@@ -213,7 +213,7 @@ void trialproperties_seq(vector<double>& parameters,double delta0,double delta1,
   *worstcasedelta=0;
   *expectedsamplesize_dm=0;
 
-  int i,j;
+  size_t i,j;
  
   //get grid of points to use
   vector<vector<double> > x;
@@ -312,7 +312,7 @@ tempvector.push_back((z.at(i).at(j+1)-z.at(i).at(j-3))/6);
   //h is a matrix which has values of h at each point
 
   vector<vector<double> > h;
-  int k;
+  size_t k;
 
   for(i=0;i<z.size();i++)
     {
@@ -393,7 +393,7 @@ void getexpectedsamplesizes(vector<double>& parameters,double delta0,double delt
   *worstcasedelta=0;
   *expectedsamplesize_dm=0;
 
-  int i,j;
+  size_t i,j;
  
   //get grid of points to use
   vector<vector<double> > x;
@@ -491,7 +491,7 @@ void getexpectedsamplesizes(vector<double>& parameters,double delta0,double delt
   //h is a matrix which has values of h at each point
 
   vector<vector<double> > h;
-  int k;
+  size_t k;
 
   for(i=0;i<z.size();i++)
     {
@@ -539,7 +539,7 @@ void getallexpectedsamplesizes(vector<double>& parameters,double delta0,double d
 {
   //This function returns the expected sample size at 50000 values of delta between delta0 and 2*delta1; this is used to plot the expected sample size of a design
 
-  int i,j;
+  size_t i,j;
  
   //get grid of points to use
   vector<vector<double> > x;
@@ -638,7 +638,7 @@ tempvector.push_back((z.at(i).at(j+1)-z.at(i).at(j-3))/6);
   //h is a matrix which has values of h at each point
 
   vector<vector<double> > h;
-  int k;
+  size_t k;
 
   for(i=0;i<z.size();i++)
     {
